==> apache-tinkerpop-3.2.11-src.zip: tinkerpop-3.2.11/gremlin-dotnet/src/Gremlin.Net/Driver/JsonMessageSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Text;
using Newtonsoft.Json;

namespace Gremlin.Net.Driver
{
    internal class JsonMessageSerializer
    {
        private const string MimeType = "application/vnd.gremlin-v2.0+json";

        public byte[] SerializeMessage(string msg)
        {
            return Encoding.UTF8.GetBytes(MessageWithHeader(msg));
        }

        private string MessageWithHeader(string messageContent)
        {
            return $"{(char) MimeType.Length}{MimeType}{messageContent}";
        }

        public TMessage DeserializeMessage<TMessage>(byte[] message)
        {
            var responseStr = Encoding.UTF8.GetString(message);
            return JsonConvert.DeserializeObject<TMessage>(responseStr);
        }
    }
}

==> apache-tinkerpop-3.4.1-src.zip: tinkerpop-3.4.1/gremlin-dotnet/src/Gremlin.Net/Driver/JsonMessageSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Text;
using Newtonsoft.Json;

namespace Gremlin.Net.Driver
{
    internal class JsonMessageSerializer
    {
        private readonly string _mimeType;

        public JsonMessageSerializer(string mimeType)
        {
            _mimeType = mimeType;
        }

        public byte[] SerializeMessage(string msg)
        {
            return Encoding.UTF8.GetBytes(MessageWithHeader(msg));
        }

        private string MessageWithHeader(string messageContent)
        {
            return $"{(char) _mimeType.Length}{_mimeType}{messageContent}";
        }

        public TMessage DeserializeMessage<TMessage>(byte[] message)
        {
            var responseStr = Encoding.UTF8.GetString(message);
            return JsonConvert.DeserializeObject<TMessage>(responseStr);
        }
    }
}
